# oneNeuron_pypi
* Packaging Perceptron - oneNeuron
  * Making single perceptron
  * Testing AND, OR, XOR & NAND logic gates with single perceptron
## Version History:
  * version=0.0.2:
    * Added all utils to this vertion